@@ -366,9 +366,9 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
       }
 
       data.cox[, (vlist()$factor_vars) := lapply(.SD, factor), .SDcols = vlist()$factor_vars]
-      label.regress2 <- mk.lev(data.cox)[, c("variable", "class", "level")]
-      data.table::setkey(data_label(), "variable", "class", "level")
-      data.table::setkey(label.regress2, "variable", "class", "level")
+      label.regress2 <- mk.lev(data.cox)[, c("variable", "level")]
+      data.table::setkey(data_label(), "variable", "level")
+      data.table::setkey(label.regress2, "variable", "level")
       label.regress <- data_label()[label.regress2]
       data.cox[[input$event_cox]] <- as.numeric(as.vector(data.cox[[input$event_cox]]))
 
