@@ -262,9 +262,9 @@ GEEModuleLinear <- function(input, output, session, data, data_label, data_varSt
         }
       }
       data.regress[, (vlist()$factor_vars) := lapply(.SD, factor), .SDcols = vlist()$factor_vars]
-      label.regress2 <- mk.lev(data.regress)[, c("variable", "class", "level")]
-      data.table::setkey(data_label(), "variable", "class", "level")
-      data.table::setkey(label.regress2, "variable", "class", "level")
+      label.regress2 <- mk.lev(data.regress)[, c("variable", "level")]
+      data.table::setkey(data_label(), "variable", "level")
+      data.table::setkey(label.regress2, "variable", "level")
       label.regress <- data_label()[label.regress2]
     }
     y <- input$dep_vars
@@ -518,9 +518,9 @@ GEEModuleLogistic <- function(input, output, session, data, data_label, data_var
         }
       }
       data.logistic[, (vlist()$factor_vars) := lapply(.SD, factor), .SDcols = vlist()$factor_vars]
-      label.regress2 <- mk.lev(data.logistic)[, c("variable", "class", "level")]
-      data.table::setkey(data_label(), "variable", "class", "level")
-      data.table::setkey(label.regress2, "variable", "class", "level")
+      label.regress2 <- mk.lev(data.logistic)[, c("variable", "level")]
+      data.table::setkey(data_label(), "variable", "level")
+      data.table::setkey(label.regress2, "variable", "level")
       label.regress <- data_label()[label.regress2]
     }
     y <- input$dep_vars
